@@ -3,7 +3,7 @@
 
 
 package BeamerReveal::Object::BeamerFrame;
-our $VERSION = '20260204.1417'; # VERSION
+our $VERSION = '20260204.1826'; # VERSION
 
 use parent 'BeamerReveal::Object';
 use Carp;
@@ -115,7 +115,7 @@ sub makeSlide {
     if ( exists $video->{embed} or $slideEmbed ) {
       $logger->log( 4, "- adding embedded video" );
       $vTemplate = $templateStore->fetch( 'html', 'video-embedded.html' );
-      my ( $mimeType, $videoContent ) = $mediaManager->videoFromStore( $video->{file},
+      my ( $mimeType ) = $mediaManager->videoFromStore( $video->{file},
 								       to_embed => 1 );
       $vStamps = { %commonStamps,
 		   VIDEOID          => 'embedded-id-' . $embeddedID++,
@@ -324,7 +324,7 @@ sub makeSlide {
   
   # notes
   my $notes = ' '; # the space is important as default, if you remove it, the notes will be sticky!
-
+  
   if ( $self->{hasnotes} ) {
     if ( $slideEmbed ) {
       my $nTemplate = $templateStore->fetch( 'html', 'note-embedded.html' );
@@ -363,10 +363,6 @@ sub makeSlide {
     
     my ( $mimeType, $slideImage ) = $mediaManager->slideFromStore( $self->{parameters}->{rawpage},
 								   to_embed => 1 );
-
-    # remember: the hasnote entry holds the note number
-    my ( undef, $notesImage ) = $mediaManager->noteFromStore( $self->{hasnotes} );
-
     my $fStamps =
       {
        DATAMENUTITLE    => $menuTitle,
@@ -386,9 +382,6 @@ sub makeSlide {
     
     my ( undef, $slideImage ) = $mediaManager->slideFromStore( $self->{parameters}->{rawpage} );
     
-    # remember: the hasnote entry holds the note number
-    my ( undef, $notesImage ) = $mediaManager->noteFromStore( $self->{hasnotes} );
-    
     my $fStamps =
       {
        DATAMENUTITLE => $menuTitle,
@@ -488,7 +481,7 @@ BeamerReveal::Object::BeamerFrame - BeamerFrame object
 
 =head1 VERSION
 
-version 20260204.1417
+version 20260204.1826
 
 =head1 SYNOPSIS
 
